package com.ruoyi.system.service.impl.projectV2;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.system.domain.projectV2.ZsyzKgxx;
import com.ruoyi.system.mapper.projectV2.ZsyzKgxxMapper;
import com.ruoyi.system.service.projectV2.IZsyzKgxxService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * 招商引资_开工信息Service业务层处理
 * 
 * @author boman
 * @date 2023-02-22
 */
@Service
public class ZsyzKgxxServiceImpl implements IZsyzKgxxService
{
    @Autowired
    private ZsyzKgxxMapper zsyzKgxxMapper;

    /**
     * 查询招商引资_开工信息
     * 
     * @param id 招商引资_开工信息ID
     * @return 招商引资_开工信息
     */
    @Override
    public ZsyzKgxx selectZsyzKgxxById(Long id)
    {
        return zsyzKgxxMapper.selectZsyzKgxxById(id);
    }

    /**
     * 查询招商引资_开工信息列表
     * 
     * @param zsyzKgxx 招商引资_开工信息
     * @return 招商引资_开工信息
     */
    @Override
    public List<ZsyzKgxx> selectZsyzKgxxList(ZsyzKgxx zsyzKgxx)
    {
        return zsyzKgxxMapper.selectZsyzKgxxList(zsyzKgxx);
    }

    /**
     * 新增招商引资_开工信息
     * 
     * @param zsyzKgxx 招商引资_开工信息
     * @return 结果
     */
    @Override
    public int insertZsyzKgxx(ZsyzKgxx zsyzKgxx)
    {
        zsyzKgxx.setCreateTime(DateUtils.getNowDate());
        return zsyzKgxxMapper.insertZsyzKgxx(zsyzKgxx);
    }

    /**
     * 修改招商引资_开工信息
     * 
     * @param zsyzKgxx 招商引资_开工信息
     * @return 结果
     */
    @Override
    public int updateZsyzKgxx(ZsyzKgxx zsyzKgxx)
    {
        zsyzKgxx.setUpdateTime(DateUtils.getNowDate());
        return zsyzKgxxMapper.updateZsyzKgxx(zsyzKgxx);
    }

    /**
     * 批量删除招商引资_开工信息
     * 
     * @param ids 需要删除的招商引资_开工信息ID
     * @return 结果
     */
    @Override
    public int deleteZsyzKgxxByIds(Long[] ids)
    {
        return zsyzKgxxMapper.deleteZsyzKgxxByIds(ids);
    }

    /**
     * 删除招商引资_开工信息信息
     * 
     * @param id 招商引资_开工信息ID
     * @return 结果
     */
    @Override
    public int deleteZsyzKgxxById(Long id)
    {
        return zsyzKgxxMapper.deleteZsyzKgxxById(id);
    }
}
