package com.ruoyi.web.controller.projectV2;

import java.util.List;

import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.system.domain.projectV2.ZsyzKgxx;
import com.ruoyi.system.service.projectV2.IZsyzKgxxService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 招商引资_开工信息Controller
 * 
 * @author boman
 * @date 2023-02-22
 */
@RestController
@RequestMapping("/projectV2/kgxx")
public class ZsyzKgxxController extends BaseController
{
    @Autowired
    private IZsyzKgxxService zsyzKgxxService;

    /**
     * 查询招商引资_开工信息列表
     */
    @PreAuthorize("@ss.hasPermi('projectV2:kgxx:list')")
    @GetMapping("/list")
    public TableDataInfo list(ZsyzKgxx zsyzKgxx)
    {
        startPage();
        List<ZsyzKgxx> list = zsyzKgxxService.selectZsyzKgxxList(zsyzKgxx);
        return getDataTable(list);
    }

    /**
     * 导出招商引资_开工信息列表
     */
    @PreAuthorize("@ss.hasPermi('projectV2:kgxx:export')")
    @Log(title = "招商引资_开工信息", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(ZsyzKgxx zsyzKgxx)
    {
        List<ZsyzKgxx> list = zsyzKgxxService.selectZsyzKgxxList(zsyzKgxx);
        ExcelUtil<ZsyzKgxx> util = new ExcelUtil<ZsyzKgxx>(ZsyzKgxx.class);
        return util.exportExcel(list, "kgxx");
    }

    /**
     * 获取招商引资_开工信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('projectV2:kgxx:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(zsyzKgxxService.selectZsyzKgxxById(id));
    }

    /**
     * 新增招商引资_开工信息
     */
    @PreAuthorize("@ss.hasPermi('projectV2:kgxx:add')")
    @Log(title = "招商引资_开工信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ZsyzKgxx zsyzKgxx)
    {
        return toAjax(zsyzKgxxService.insertZsyzKgxx(zsyzKgxx));
    }

    /**
     * 修改招商引资_开工信息
     */
    @PreAuthorize("@ss.hasPermi('projectV2:kgxx:edit')")
    @Log(title = "招商引资_开工信息", businessType = BusinessType.UPDATE)
    @PostMapping("/put")
    public AjaxResult edit(@RequestBody ZsyzKgxx zsyzKgxx)
    {
        return toAjax(zsyzKgxxService.updateZsyzKgxx(zsyzKgxx));
    }

    /**
     * 删除招商引资_开工信息
     */
    @PreAuthorize("@ss.hasPermi('projectV2:kgxx:remove')")
    @Log(title = "招商引资_开工信息", businessType = BusinessType.DELETE)
	@GetMapping("/delete/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(zsyzKgxxService.deleteZsyzKgxxByIds(ids));
    }
}
